==> org.Mm.eg.db_2.4.1.tar.gz: org.Mm.eg.db/man/org.Mm.egMAP.Rd <==
\name{org.Mm.egMAP}
\alias{org.Mm.egMAP}
\alias{org.Mm.egMAP2EG}
\title{Map between Entrez Gene Identifiers and cytogenetic maps/bands}
\description{
   org.Mm.egMAP is an R object that provides mappings between
   entrez gene identifiers and cytoband locations.
}
\details{
  Each entrez gene identifier is mapped to a vector of cytoband locations. The
  vector length may be one or longer, if there are multiple reported
  chromosomal locations for a given gene. An \code{NA} is reported for
  any entrez gene identifiers that cannot be mapped to a cytoband at this time.
  
  The physical location of each band on a chromosome can be obtained
  from another object named "organism"CYTOLOC in a separate data
  package for human(humanCHRLOC), mouse(mouseCHRLOC), and rat(ratCHRLOC).  
  
  Mappings were based on data provided by: Entrez Gene  
  ftp://ftp.ncbi.nlm.nih.gov/gene/DATA  
  With a date stamp from the source of: 2010-Mar1

}
\references{
  \url{http://www.ncbi.nlm.nih.gov}
}
\examples{
        x <- org.Mm.egMAP
        # Get the entrez gene identifiers that are mapped to any cytoband
        mapped_genes <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_genes])
        if(length(xx) > 0) {
          # Get the ids for the first five genes
          xx[1:5]
          # Get the first one
          xx[[1]]
        }
        #For the reverse map org.Mm.egMAP2EG
        x <- org.Mm.egMAP2EG
        # Get the cytobands that are mapped to any entrez gene id
        mapped_bands <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_bands])
        if(length(xx) > 0) {
          # Get the bands for the first five genes
          xx[1:5]
          # Get the first one
          xx[[1]]
        }
}
\keyword{datasets}

==> org.Mm.eg.db_2.4.6.tar.gz: org.Mm.eg.db/man/org.Mm.egMAP.Rd <==
\name{org.Mm.egMAP}
\alias{org.Mm.egMAP}
\alias{org.Mm.egMAP2EG}
\title{Map between Entrez Gene Identifiers and cytogenetic maps/bands}
\description{
   org.Mm.egMAP is an R object that provides mappings between
   entrez gene identifiers and cytoband locations.
}
\details{
  Each entrez gene identifier is mapped to a vector of cytoband locations. The
  vector length may be one or longer, if there are multiple reported
  chromosomal locations for a given gene. An \code{NA} is reported for
  any entrez gene identifiers that cannot be mapped to a cytoband at this time.
  
  The physical location of each band on a chromosome can be obtained
  from another object named "organism"CYTOLOC in a separate data
  package for human(humanCHRLOC), mouse(mouseCHRLOC), and rat(ratCHRLOC).  
  
  Mappings were based on data provided by: Entrez Gene  
  ftp://ftp.ncbi.nlm.nih.gov/gene/DATA  
  With a date stamp from the source of: 2010-Sep7

}
\references{
  \url{http://www.ncbi.nlm.nih.gov}
}
\examples{
        x <- org.Mm.egMAP
        # Get the entrez gene identifiers that are mapped to any cytoband
        mapped_genes <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_genes])
        if(length(xx) > 0) {
          # Get the ids for the first five genes
          xx[1:5]
          # Get the first one
          xx[[1]]
        }
        #For the reverse map org.Mm.egMAP2EG
        x <- org.Mm.egMAP2EG
        # Get the cytobands that are mapped to any entrez gene id
        mapped_bands <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_bands])
        if(length(xx) > 0) {
          # Get the bands for the first five genes
          xx[1:5]
          # Get the first one
          xx[[1]]
        }
}
\keyword{datasets}
